Struct InlayHint
pub struct InlayHint {
pub position: Position,
pub label: InlayHintLabel,
pub kind: Option<InlayHintKind>,
pub text_edits: Option<Vec<TextEdit>>,
pub tooltip: Option<InlayHintTooltip>,
pub padding_left: Option<bool>,
pub padding_right: Option<bool>,
pub data: Option<Value>,
}Expand description
Inlay hint information.
@since 3.17.0
Fields
position: PositionThe position of this hint.
label: InlayHintLabelThe label of this hint. A human readable string or an array of InlayHintLabelPart label parts.
Note that neither the string nor the label part can be empty.
kind: Option<InlayHintKind>The kind of this hint. Can be omitted in which case the client should fall back to a reasonable default.
text_edits: Option<Vec<TextEdit>>Optional text edits that are performed when accepting this inlay hint.
Note that edits are expected to change the document so that the inlay hint (or its nearest variant) is now part of the document and the inlay hint itself is now obsolete.
Depending on the client capability inlayHint.resolveSupport clients
might resolve this property late using the resolve request.
tooltip: Option<InlayHintTooltip>The tooltip text when you hover over this item.
Depending on the client capability inlayHint.resolveSupport clients
might resolve this property late using the resolve request.
padding_left: Option<bool>Render padding before the hint.
Note: Padding should use the editor’s background color, not the background color of the hint itself. That means padding can be used to visually align/separate an inlay hint.
padding_right: Option<bool>Render padding after the hint.
Note: Padding should use the editor’s background color, not the background color of the hint itself. That means padding can be used to visually align/separate an inlay hint.
data: Option<Value>A data entry field that is preserved on a inlay hint between
a textDocument/inlayHint and a inlayHint/resolve request.