Struct Uri
pub struct Uri(/* private fields */);Expand description
Newtype struct around fluent_uri::Uri<String> with serialization implementations that use as_str() and ‘from_str()’ respectively.
Methods from Deref<Target = Uri<String>>
Returns the authority component.
pub fn path(&'i self) -> &'o Path
pub fn path(&'i self) -> &'o Path
pub fn is_relative(&self) -> bool
pub fn is_relative(&self) -> bool
Returns true if the URI reference is relative, i.e., without a scheme.
Note that this method is not the opposite of is_absolute.
Examples
use fluent_uri::Uri;
let uri = Uri::parse("/path/to/file")?;
assert!(uri.is_relative());
let uri = Uri::parse("http://example.com/")?;
assert!(!uri.is_relative());pub fn is_absolute(&self) -> bool
pub fn is_absolute(&self) -> bool
Returns true if the URI reference is absolute, i.e., with a scheme and without a fragment.
Note that this method is not the opposite of is_relative.
Examples
use fluent_uri::Uri;
let uri = Uri::parse("http://example.com/")?;
assert!(uri.is_absolute());
let uri = Uri::parse("http://example.com/#title1")?;
assert!(!uri.is_absolute());
let uri = Uri::parse("/path/to/file")?;
assert!(!uri.is_absolute());Trait Implementations
impl<'de> Deserialize<'de> for Uri
impl<'de> Deserialize<'de> for Uri
fn deserialize<D>(
deserializer: D,
) -> Result<Uri, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<Uri, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Uri
impl Ord for Uri
impl Ord for Uri
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
impl PartialOrd for Uri
impl PartialOrd for Uri
impl Serialize for Uri
impl Serialize for Uri
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more